@@ -2,87 +2,90 @@ var namespaces_dup =
 [
     [ "flecs", null, [
       [ "_", "namespaceflecs_1_1__.html", "namespaceflecs_1_1__" ],
-      [ "actual_type", "structflecs_1_1actual__type.html", null ],
-      [ "actual_type< T, if_not_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
-      [ "actual_type< T, if_t< is_pair< T >::value > >", "structflecs_1_1actual__type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
-      [ "alert", "structflecs_1_1alert.html", "structflecs_1_1alert" ],
+      [ "untyped_component", "structflecs_1_1untyped__component.html", "structflecs_1_1untyped__component" ],
+      [ "component", "structflecs_1_1component.html", "structflecs_1_1component" ],
+      [ "entity", "structflecs_1_1entity.html", "structflecs_1_1entity" ],
+      [ "entity_view", "structflecs_1_1entity__view.html", "structflecs_1_1entity__view" ],
+      [ "untyped_field", "structflecs_1_1untyped__field.html", "structflecs_1_1untyped__field" ],
+      [ "field", "structflecs_1_1field.html", "structflecs_1_1field" ],
+      [ "ref", "structflecs_1_1ref.html", null ],
+      [ "iter", "structflecs_1_1iter.html", "structflecs_1_1iter" ],
+      [ "is_flecs_constructible", "structflecs_1_1is__flecs__constructible.html", null ],
       [ "alert_builder", "structflecs_1_1alert__builder.html", null ],
       [ "alert_builder_i", "structflecs_1_1alert__builder__i.html", "structflecs_1_1alert__builder__i" ],
       [ "alerts", "structflecs_1_1alerts.html", "structflecs_1_1alerts" ],
+      [ "alert", "structflecs_1_1alert.html", "structflecs_1_1alert" ],
       [ "app_builder", "structflecs_1_1app__builder.html", null ],
-      [ "arity", "structflecs_1_1arity.html", null ],
-      [ "array", "structflecs_1_1array.html", null ],
-      [ "array< T, Size, enable_if_t< Size !=0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html", null ],
-      [ "array< T, Size, enable_if_t< Size==0 > >", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html", null ],
-      [ "array_iterator", "structflecs_1_1array__iterator.html", null ],
-      [ "base_arg_type", "structflecs_1_1base__arg__type.html", null ],
-      [ "base_type", "structflecs_1_1base__type.html", null ],
-      [ "bitmask", "structflecs_1_1bitmask.html", null ],
-      [ "component", "structflecs_1_1component.html", "structflecs_1_1component" ],
-      [ "cursor", "structflecs_1_1cursor.html", "structflecs_1_1cursor" ],
-      [ "entity", "structflecs_1_1entity.html", "structflecs_1_1entity" ],
       [ "entity_builder", "structflecs_1_1entity__builder.html", "structflecs_1_1entity__builder" ],
-      [ "entity_view", "structflecs_1_1entity__view.html", "structflecs_1_1entity__view" ],
-      [ "enum_data", "structflecs_1_1enum__data.html", "structflecs_1_1enum__data" ],
-      [ "enum_last", "structflecs_1_1enum__last.html", null ],
-      [ "event_builder", "structflecs_1_1event__builder.html", null ],
       [ "event_builder_base", "structflecs_1_1event__builder__base.html", "structflecs_1_1event__builder__base" ],
+      [ "event_builder", "structflecs_1_1event__builder.html", null ],
       [ "event_builder_typed", "structflecs_1_1event__builder__typed.html", null ],
-      [ "field", "structflecs_1_1field.html", "structflecs_1_1field" ],
-      [ "first_arg", "structflecs_1_1first__arg.html", null ],
-      [ "first_arg_impl", "structflecs_1_1first__arg__impl.html", null ],
-      [ "first_arg_impl< Func, _::arg_list< T, Args ... > >", "structflecs_1_1first__arg__impl_3_01Func_00_01___1_1arg__list_3_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
       [ "id", "structflecs_1_1id.html", "structflecs_1_1id" ],
-      [ "is_actual", "structflecs_1_1is__actual.html", null ],
-      [ "is_callable", "structflecs_1_1is__callable.html", null ],
-      [ "is_flecs_constructible", "structflecs_1_1is__flecs__constructible.html", null ],
-      [ "is_pair", "structflecs_1_1is__pair.html", null ],
-      [ "is_same", "classflecs_1_1is__same.html", null ],
-      [ "iter", "structflecs_1_1iter.html", "structflecs_1_1iter" ],
-      [ "iter_iterable", "structflecs_1_1iter__iterable.html", "structflecs_1_1iter__iterable" ],
-      [ "iterable", "structflecs_1_1iterable.html", "structflecs_1_1iterable" ],
+      [ "cursor", "structflecs_1_1cursor.html", "structflecs_1_1cursor" ],
+      [ "bitmask", "structflecs_1_1bitmask.html", null ],
+      [ "opaque", "structflecs_1_1opaque.html", "structflecs_1_1opaque" ],
       [ "metric_builder", "structflecs_1_1metric__builder.html", null ],
       [ "metrics", "structflecs_1_1metrics.html", "structflecs_1_1metrics" ],
-      [ "observer", "structflecs_1_1observer.html", "structflecs_1_1observer" ],
       [ "observer_builder", "structflecs_1_1observer__builder.html", null ],
       [ "observer_builder_i", "structflecs_1_1observer__builder__i.html", "structflecs_1_1observer__builder__i" ],
-      [ "opaque", "structflecs_1_1opaque.html", "structflecs_1_1opaque" ],
-      [ "page_iterable", "structflecs_1_1page__iterable.html", null ],
-      [ "pair", "structflecs_1_1pair.html", null ],
-      [ "pipeline", "structflecs_1_1pipeline.html", null ],
+      [ "observer", "structflecs_1_1observer.html", "structflecs_1_1observer" ],
       [ "pipeline_builder", "structflecs_1_1pipeline__builder.html", null ],
       [ "pipeline_builder_i", "structflecs_1_1pipeline__builder__i.html", null ],
-      [ "query", "structflecs_1_1query.html", null ],
-      [ "query_base", "structflecs_1_1query__base.html", "structflecs_1_1query__base" ],
+      [ "pipeline", "structflecs_1_1pipeline.html", null ],
       [ "query_builder", "structflecs_1_1query__builder.html", null ],
       [ "query_builder_i", "structflecs_1_1query__builder__i.html", "structflecs_1_1query__builder__i" ],
-      [ "ref", "structflecs_1_1ref.html", null ],
-      [ "scoped_world", "structflecs_1_1scoped__world.html", null ],
+      [ "query", "structflecs_1_1query.html", null ],
+      [ "query_base", "structflecs_1_1query__base.html", "structflecs_1_1query__base" ],
       [ "script_builder", "structflecs_1_1script__builder.html", null ],
-      [ "second_arg", "structflecs_1_1second__arg.html", null ],
-      [ "second_arg_impl", "structflecs_1_1second__arg__impl.html", null ],
-      [ "second_arg_impl< Func, _::arg_list< First, T, Args ... > >", "structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
       [ "stats", "structflecs_1_1stats.html", null ],
-      [ "string", "structflecs_1_1string.html", null ],
-      [ "string_view", "structflecs_1_1string__view.html", null ],
-      [ "stringstream", "structflecs_1_1stringstream.html", null ],
-      [ "system", "structflecs_1_1system.html", "structflecs_1_1system" ],
       [ "system_builder", "structflecs_1_1system__builder.html", null ],
       [ "system_builder_i", "structflecs_1_1system__builder__i.html", "structflecs_1_1system__builder__i" ],
       [ "system_runner_fluent", "structflecs_1_1system__runner__fluent.html", null ],
+      [ "system", "structflecs_1_1system.html", "structflecs_1_1system" ],
+      [ "term_ref_builder_i", "structflecs_1_1term__ref__builder__i.html", null ],
+      [ "term_builder_i", "structflecs_1_1term__builder__i.html", "structflecs_1_1term__builder__i" ],
+      [ "term", "structflecs_1_1term.html", null ],
+      [ "timer", "structflecs_1_1timer.html", "structflecs_1_1timer" ],
+      [ "units", "structflecs_1_1units.html", null ],
+      [ "pair", "structflecs_1_1pair.html", null ],
+      [ "is_pair", "structflecs_1_1is__pair.html", null ],
+      [ "actual_type", "structflecs_1_1actual__type.html", null ],
+      [ "actual_type&lt; T, if_not_t&lt; is_pair&lt; T &gt;::value &gt; &gt;", "structflecs_1_1actual__type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
+      [ "actual_type&lt; T, if_t&lt; is_pair&lt; T &gt;::value &gt; &gt;", "structflecs_1_1actual__type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html", null ],
+      [ "base_type", "structflecs_1_1base__type.html", null ],
+      [ "base_arg_type", "structflecs_1_1base__arg__type.html", null ],
+      [ "is_actual", "structflecs_1_1is__actual.html", null ],
+      [ "untyped_ref", "structflecs_1_1untyped__ref.html", "structflecs_1_1untyped__ref" ],
       [ "table", "structflecs_1_1table.html", "structflecs_1_1table" ],
       [ "table_range", "structflecs_1_1table__range.html", "structflecs_1_1table__range" ],
-      [ "term", "structflecs_1_1term.html", null ],
-      [ "term_builder_i", "structflecs_1_1term__builder__i.html", "structflecs_1_1term__builder__i" ],
-      [ "term_ref_builder_i", "structflecs_1_1term__ref__builder__i.html", null ],
-      [ "timer", "structflecs_1_1timer.html", "structflecs_1_1timer" ],
       [ "type", "structflecs_1_1type.html", "structflecs_1_1type" ],
-      [ "units", "structflecs_1_1units.html", null ],
-      [ "untyped_component", "structflecs_1_1untyped__component.html", "structflecs_1_1untyped__component" ],
-      [ "untyped_field", "structflecs_1_1untyped__field.html", "structflecs_1_1untyped__field" ],
-      [ "untyped_ref", "structflecs_1_1untyped__ref.html", "structflecs_1_1untyped__ref" ],
+      [ "array_iterator", "structflecs_1_1array__iterator.html", null ],
+      [ "array", "structflecs_1_1array.html", null ],
+      [ "array&lt; T, Size, enable_if_t&lt; Size !=0 &gt; &gt;", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html", null ],
+      [ "array&lt; T, Size, enable_if_t&lt; Size==0 &gt; &gt;", "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html", null ],
+      [ "enum_data", "structflecs_1_1enum__data.html", "structflecs_1_1enum__data" ],
+      [ "enum_last", "structflecs_1_1enum__last.html", null ],
+      [ "is_callable", "structflecs_1_1is__callable.html", null ],
+      [ "arity", "structflecs_1_1arity.html", null ],
+      [ "first_arg_impl", "structflecs_1_1first__arg__impl.html", null ],
+      [ "first_arg_impl&lt; Func, _::arg_list&lt; T, Args ... &gt; &gt;", "structflecs_1_1first__arg__impl_3_01Func_00_01___1_1arg__list_3_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
+      [ "first_arg", "structflecs_1_1first__arg.html", null ],
+      [ "second_arg_impl", "structflecs_1_1second__arg__impl.html", null ],
+      [ "second_arg_impl&lt; Func, _::arg_list&lt; First, T, Args ... &gt; &gt;", "structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html", null ],
+      [ "second_arg", "structflecs_1_1second__arg.html", null ],
+      [ "iter_iterable", "structflecs_1_1iter__iterable.html", "structflecs_1_1iter__iterable" ],
+      [ "page_iterable", "structflecs_1_1page__iterable.html", null ],
       [ "worker_iterable", "structflecs_1_1worker__iterable.html", null ],
+      [ "iterable", "structflecs_1_1iterable.html", "structflecs_1_1iterable" ],
+      [ "string", "structflecs_1_1string.html", null ],
+      [ "string_view", "structflecs_1_1string__view.html", null ],
+      [ "stringstream", "structflecs_1_1stringstream.html", null ],
+      [ "condition", "structflecs_1_1condition.html", null ],
+      [ "condition&lt; false &gt;", "structflecs_1_1condition_3_01false_01_4.html", null ],
+      [ "condition&lt; true &gt;", "structflecs_1_1condition_3_01true_01_4.html", null ],
       [ "world", "structflecs_1_1world.html", "structflecs_1_1world" ],
+      [ "scoped_world", "structflecs_1_1scoped__world.html", null ],
+      [ "is_same", "classflecs_1_1is__same.html", null ],
       [ "pair_first_t", "group__cpp__pair__type.html#gafbe761180d0c10d50a1ddb50f6f66eeb", null ],
       [ "pair_second_t", "group__cpp__pair__type.html#ga8c664b7fef1bb65d68e3155a0c908e23", null ],
       [ "pair_type_t", "group__cpp__pair__type.html#ga301d90dff367ff0b7974bb189b7ea1b7", null ],
@@ -101,8 +104,8 @@ var namespaces_dup =
       [ "array", "structflecs_1_1world.html#a290dbe18df4d2739f6e3412470f7e421", null ],
       [ "array", "structflecs_1_1world.html#a54a7c8f1b846be215f0fc2d86298603e", null ],
       [ "bit", "group__cpp__addons__meta.html#gab0eec710bc70c33fb74f4285a568a9f9", null ],
-      [ "component", "structflecs_1_1world.html#gae215acdf24d5c8edcfc56c2c003e58f2", null ],
       [ "component", "structflecs_1_1world.html#gadf19fec48c5a4b372b9858eb5e1b6bd3", null ],
+      [ "component", "structflecs_1_1world.html#gae215acdf24d5c8edcfc56c2c003e58f2", null ],
       [ "constant", "group__cpp__addons__meta.html#ga69e3ff4b179e3b0b464a9f9d72efa772", null ],
       [ "cursor", "structflecs_1_1world.html#ga7801bddc835d400dc71c6261f64fba2b", null ],
       [ "cursor", "structflecs_1_1world.html#af14e2f21de0df9ac42c914b5bf942b8b", null ],
@@ -113,8 +116,8 @@ var namespaces_dup =
       [ "doc_name", "structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
       [ "doc_uuid", "structflecs_1_1entity__view.html#gaa9f623f19cb2338d558dc5270fc4926e", null ],
       [ "each", "structflecs_1_1world.html#aa0c30cbd4444e54dfa0258a87fd9b5a0", null ],
-      [ "each", "structflecs_1_1world.html#a6eadaf81c342aac9d72edda33071a880", null ],
       [ "each", "structflecs_1_1world.html#ab92814d4a48f2e7b25f9b9dec2059f43", null ],
+      [ "each", "structflecs_1_1world.html#a6eadaf81c342aac9d72edda33071a880", null ],
       [ "emit", "structflecs_1_1entity__view.html#a5dbe98d0b92a17ef92636d9fd1f71bf1", null ],
       [ "emit", "structflecs_1_1entity__view.html#af5215e7570046d039308366041644e94", null ],
       [ "emit", "structflecs_1_1entity__view.html#aa273be7c42fc44329c66ea26482ac08e", null ],
@@ -144,12 +147,12 @@ var namespaces_dup =
       [ "import", "structflecs_1_1world.html#a30a3e86d6ec3672bc1056dd9b143f9e2", null ],
       [ "interval", "structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0", null ],
       [ "interval", "structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f", null ],
-      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
       [ "member", "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097", null ],
-      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
+      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
       [ "member", "group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7", null ],
-      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
+      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
       [ "member", "group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd", null ],
+      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
       [ "member", "group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6", null ],
       [ "member", "group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975", null ],
       [ "member", "group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f", null ],
@@ -161,21 +164,21 @@ var namespaces_dup =
       [ "metric", "structflecs_1_1world.html#ga3ad069707daed3ddabb4e5a13ac3b4d4", null ],
       [ "module", "structflecs_1_1world.html#gac9a0f511976962585bd5e53451b21b71", null ],
       [ "observe", "structflecs_1_1entity__builder.html#ab6050fb9a45b5bcbe5e38bdc9964d7e6", null ],
-      [ "observe", "structflecs_1_1entity__builder.html#a49e77241334232d5acb67fd92a40f6fc", null ],
       [ "observe", "structflecs_1_1entity__builder.html#a19adebc4c18a744e1258996ac333421e", null ],
+      [ "observe", "structflecs_1_1entity__builder.html#a49e77241334232d5acb67fd92a40f6fc", null ],
       [ "observer", "structflecs_1_1world.html#a876541023d75a8d2aef6206f61581a1e", null ],
       [ "observer", "structflecs_1_1world.html#gab79584a6a6a97e6027511c3966d4187c", null ],
       [ "pair", "structflecs_1_1world.html#aa106734ba4c35baf4cbcb83aeb56591d", null ],
       [ "pair", "structflecs_1_1world.html#a01d0ae38e523fbae689cb6e47ff210cf", null ],
       [ "pair", "structflecs_1_1world.html#ae3ecd53823b33c8d633ab60f65381e4f", null ],
-      [ "pipeline", "structflecs_1_1world.html#ga7b2a5cf41e12b0ebafb1633be74aa11d", null ],
       [ "pipeline", "structflecs_1_1world.html#a6c0b631ecdd858fb1e5fd44653e554f6", null ],
+      [ "pipeline", "structflecs_1_1world.html#ga7b2a5cf41e12b0ebafb1633be74aa11d", null ],
       [ "prefab", "structflecs_1_1world.html#gac85030c68a4f438218d42b9ec3a2b450", null ],
       [ "prefab", "structflecs_1_1world.html#gaf2175c4b55288f38daa081c2d6b95ec4", null ],
       [ "primitive", "structflecs_1_1world.html#a108fe405178ca7e719d70fdea54ff9c7", null ],
       [ "progress", "structflecs_1_1world.html#af292376679173c4f14e25947ce7eaa45", null ],
-      [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
       [ "quantity", "group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536", null ],
+      [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
       [ "quantity", "group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f", null ],
       [ "query", "structflecs_1_1world.html#ga3ba22415d130b509e5eeac5e1f0a6c93", null ],
       [ "query", "structflecs_1_1world.html#ac8a5e864dc1d1333ed4606af25669283", null ],
@@ -191,8 +194,8 @@ var namespaces_dup =
       [ "set_doc_link", "structflecs_1_1entity__builder.html#ga9898033ab60172b2ed5b675b99b96426", null ],
       [ "set_doc_name", "structflecs_1_1entity__builder.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
       [ "set_doc_uuid", "structflecs_1_1entity__builder.html#ga1f1be3c70cc2b1174a843ab35da5cf66", null ],
-      [ "set_json", "structflecs_1_1entity__builder.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
       [ "set_json", "structflecs_1_1entity__builder.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
+      [ "set_json", "structflecs_1_1entity__builder.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
       [ "set_json", "structflecs_1_1entity__builder.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
       [ "set_json", "structflecs_1_1entity__builder.html#gafbf781155476437fcf38d37e2380f8a8", null ],
       [ "set_json", "structflecs_1_1entity__builder.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
@@ -210,8 +213,8 @@ var namespaces_dup =
       [ "strip_generation", "world_8hpp.html#a339a34f50310d7a3f7d0f3e6372a89bd", null ],
       [ "system", "structflecs_1_1world.html#a111f6b0e868528ac6cc4d2259fff1464", null ],
       [ "system", "structflecs_1_1world.html#ga044c2bfc37acb9f970bb896dea58ad8a", null ],
-      [ "term", "structflecs_1_1world.html#a678e5634ddb790fae997b540f033a226", null ],
       [ "term", "structflecs_1_1world.html#ad006cb298624eb92c1135afa99376997", null ],
+      [ "term", "structflecs_1_1world.html#a678e5634ddb790fae997b540f033a226", null ],
       [ "term", "structflecs_1_1world.html#gae10e0f557ad931415741ad2f9ae533e6", null ],
       [ "timeout", "structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b", null ],
       [ "timeout", "structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543", null ],
