@@ -1,16 +1,17 @@
 var structecs__observer__desc__t =
 [
-    [ "binding_ctx", "structecs__observer__desc__t.html#a01a27f49501eb70c1b1ddc35ee7887e9", null ],
-    [ "binding_ctx_free", "structecs__observer__desc__t.html#a5ac9c1d6b5cc62ee9923aa4231ec59e7", null ],
+    [ "_canary", "structecs__observer__desc__t.html#ae3ee3ad70b6ba42e50b44497eca8088c", null ],
     [ "callback", "structecs__observer__desc__t.html#a9da01e3ff1133d54ab51676b2ba3236e", null ],
+    [ "callback_ctx", "structecs__observer__desc__t.html#a54316ee7ac18a0728b542bdfffab4da1", null ],
+    [ "callback_ctx_free", "structecs__observer__desc__t.html#a7ea0627d3d36c7203e7d2ce3195e932e", null ],
     [ "ctx", "structecs__observer__desc__t.html#a6efbebea0dceda4d3c3d5ea4e45ae79d", null ],
     [ "ctx_free", "structecs__observer__desc__t.html#a1465d132f3c126f795f7f8163b9c35c9", null ],
     [ "entity", "structecs__observer__desc__t.html#a26f3f2811d6b05bb438eaf307c7a437f", null ],
-    [ "events", "structecs__observer__desc__t.html#a4f2b3232b25e085a8a7afea8f6cd1722", null ],
-    [ "filter", "structecs__observer__desc__t.html#a2917bf67385a2620e207efc803cb730a", null ],
+    [ "events", "structecs__observer__desc__t.html#adfdea33ea4d483000c8b5fda1ea80059", null ],
     [ "last_event_id", "structecs__observer__desc__t.html#a541fcd6f82f7cb9c93f19d3574502d93", null ],
-    [ "observable", "structecs__observer__desc__t.html#a6fbf0efe8d795a7b75b7ad9d62275eb7", null ],
+    [ "query", "structecs__observer__desc__t.html#a6fba3bfb62f1ff762a90cb5caaaddd3c", null ],
     [ "run", "structecs__observer__desc__t.html#acb28bd113c9812726a96aec748de1909", null ],
-    [ "term_index", "structecs__observer__desc__t.html#a3b9c95261951a43db60bdf6d687fb5aa", null ],
+    [ "run_ctx", "structecs__observer__desc__t.html#a15ba878b6ed171f7e1865f665d658015", null ],
+    [ "run_ctx_free", "structecs__observer__desc__t.html#a06ab02e971f8d1660b9a0cf2b30f7b93", null ],
     [ "yield_existing", "structecs__observer__desc__t.html#acac94b9e206eb7433c97753bf13c484f", null ]
 ];
\ No newline at end of file
